/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // granatierui.rc
  0x0,0x0,0x1,0x37,
  0x3c,
  0x3f,0x78,0x6d,0x6c,0x20,0x76,0x65,0x72,0x73,0x69,0x6f,0x6e,0x3d,0x22,0x31,0x2e,
  0x30,0x22,0x20,0x65,0x6e,0x63,0x6f,0x64,0x69,0x6e,0x67,0x3d,0x22,0x55,0x54,0x46,
  0x2d,0x38,0x22,0x3f,0x3e,0xa,0x3c,0x21,0x44,0x4f,0x43,0x54,0x59,0x50,0x45,0x20,
  0x67,0x75,0x69,0x20,0x53,0x59,0x53,0x54,0x45,0x4d,0x20,0x22,0x6b,0x70,0x61,0x72,
  0x74,0x67,0x75,0x69,0x2e,0x64,0x74,0x64,0x22,0x3e,0xa,0x3c,0x67,0x75,0x69,0x20,
  0x6e,0x61,0x6d,0x65,0x3d,0x22,0x47,0x72,0x61,0x6e,0x61,0x74,0x69,0x65,0x72,0x22,
  0x20,0x76,0x65,0x72,0x73,0x69,0x6f,0x6e,0x3d,0x22,0x31,0x22,0x3e,0xa,0x20,0x20,
  0x20,0x20,0x3c,0x4d,0x65,0x6e,0x75,0x42,0x61,0x72,0x3e,0xa,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x3c,0x4d,0x65,0x6e,0x75,0x20,0x6e,0x61,0x6d,0x65,0x3d,0x22,
  0x67,0x61,0x6d,0x65,0x22,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x3c,0x41,0x63,0x74,0x69,0x6f,0x6e,0x20,0x6e,0x61,0x6d,0x65,0x3d,
  0x22,0x6c,0x65,0x76,0x65,0x6c,0x22,0x20,0x2f,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x3c,0x2f,0x4d,0x65,0x6e,0x75,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x3c,0x4d,0x65,0x6e,0x75,0x20,0x6e,0x61,0x6d,0x65,0x3d,0x22,0x73,
  0x65,0x74,0x74,0x69,0x6e,0x67,0x73,0x22,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x41,0x63,0x74,0x69,0x6f,0x6e,0x20,0x6e,0x61,
  0x6d,0x65,0x3d,0x22,0x73,0x6f,0x75,0x6e,0x64,0x73,0x22,0x20,0x2f,0x3e,0xa,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x2f,0x4d,0x65,0x6e,0x75,0x3e,0xa,0x20,
  0x20,0x20,0x20,0x3c,0x2f,0x4d,0x65,0x6e,0x75,0x42,0x61,0x72,0x3e,0xa,0x3c,0x2f,
  0x67,0x75,0x69,0x3e,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // granatier
  0x0,0x9,
  0x8,0x48,0x72,0xc2,
  0x0,0x67,
  0x0,0x72,0x0,0x61,0x0,0x6e,0x0,0x61,0x0,0x74,0x0,0x69,0x0,0x65,0x0,0x72,
    // granatierui.rc
  0x0,0xe,
  0xd,0x92,0xcb,0xc3,
  0x0,0x67,
  0x0,0x72,0x0,0x61,0x0,0x6e,0x0,0x61,0x0,0x74,0x0,0x69,0x0,0x65,0x0,0x72,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9d,0xfa,0x81,0xf4,0x90,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9d,0xfa,0x81,0xf4,0x90,
  // :/kxmlgui5/granatier
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9d,0xfa,0x81,0xf4,0x90,
  // :/kxmlgui5/granatier/granatierui.rc
  0x0,0x0,0x0,0x2e,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9d,0xfa,0x81,0xf4,0x90,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_granatier)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_granatier)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_granatier)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_granatier)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_granatier)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_granatier)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
